==> ejc-purchasingmanagement-impl-3.0.0-20220511.150614-65-sources.jar: com/ejianc/business/purchasingmanagement/bean/WeighingInfoEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 称重信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_weighingInfo")
public class WeighingInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="number_plate")
    private String numberPlate; // 车牌号
    @TableField(value="weighing_time")
    private Date weighingTime; // 称重时间
    @TableField(value="purchasereceipt_id")
    private Long purchasereceiptId; // 收货单ID
    @TableField(value="pound_room_id")
    private Long poundRoomId; // 磅房ID
    @TableField(value="camera_id")
    private Long cameraId; // 摄像头ID
    @TableField(value="weigher_id")
    private Long weigherId; // 磅头ID
    @TableField(value="weighing_method")
    private Integer weighingMethod; // 称重方式 0,一次称重  1,毛重  2,皮重 
    @TableField(value="print")
    private Integer print; // 是否打印   
    @TableField(value="send_or_receive")
    private Integer sendOrReceive; // 收发类型 0,收货 1,发货  
    @TableField(value="first_time_id")
    private Long firstTimeId; // 上次称重ID
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="weight")
    private BigDecimal  weight;//称重重量

    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getWeighingTime() {
        return weighingTime;
    }

    public void setWeighingTime(Date weighingTime) {
        this.weighingTime = weighingTime;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public Long getPoundRoomId() {
        return poundRoomId;
    }

    public void setPoundRoomId(Long poundRoomId) {
        this.poundRoomId = poundRoomId;
    }
    public Long getCameraId() {
        return cameraId;
    }

    public void setCameraId(Long cameraId) {
        this.cameraId = cameraId;
    }
    public Long getWeigherId() {
        return weigherId;
    }

    public void setWeigherId(Long weigherId) {
        this.weigherId = weigherId;
    }
    public Integer getWeighingMethod() {
        return weighingMethod;
    }

    public void setWeighingMethod(Integer weighingMethod) {
        this.weighingMethod = weighingMethod;
    }
    public Integer getPrint() {
        return print;
    }

    public void setPrint(Integer print) {
        this.print = print;
    }
    public Integer getSendOrReceive() {
        return sendOrReceive;
    }

    public void setSendOrReceive(Integer sendOrReceive) {
        this.sendOrReceive = sendOrReceive;
    }
    public Long getFirstTimeId() {
        return firstTimeId;
    }

    public void setFirstTimeId(Long firstTimeId) {
        this.firstTimeId = firstTimeId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220707.064339-131-sources.jar: com/ejianc/business/purchasingmanagement/bean/WeighingInfoEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 称重信息
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_weighingInfo")
public class WeighingInfoEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="number_plate")
    private String numberPlate; // 车牌号
    @TableField(value="weighing_time")
    private Date weighingTime; // 称重时间
    @TableField(value="purchasereceipt_id")
    private Long purchasereceiptId; // 收货单ID
    @TableField(value="pound_room_id")
    private Long poundRoomId; // 磅房ID
    @TableField(value="camera_id")
    private Long cameraId; // 摄像头ID
    @TableField(value="weigher_id")
    private Long weigherId; // 磅头ID
    @TableField(value="weighing_method")
    private Integer weighingMethod; // 称重方式 0,一次称重  1,毛重  2,皮重 
    @TableField(value="print")
    private Integer print; // 是否打印   
    @TableField(value="send_or_receive")
    private Integer sendOrReceive; // 收发类型 0,收货 1,发货  
    @TableField(value="first_time_id")
    private Long firstTimeId; // 上次称重ID
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="weight")
    private BigDecimal  weight;//称重重量
    @TableField(value="materialplan_id")
    private Long materialplanId;  //定料计划
    @TableField(value="net_weight")
    private BigDecimal netWeight;  // 净重

    public Long getMaterialplanId() {
        return materialplanId;
    }

    public void setMaterialplanId(Long materialplanId) {
        this.materialplanId = materialplanId;
    }

    public BigDecimal getNetWeight() {
        return netWeight;
    }

    public void setNetWeight(BigDecimal netWeight) {
        this.netWeight = netWeight;
    }

    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getWeighingTime() {
        return weighingTime;
    }

    public void setWeighingTime(Date weighingTime) {
        this.weighingTime = weighingTime;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public Long getPoundRoomId() {
        return poundRoomId;
    }

    public void setPoundRoomId(Long poundRoomId) {
        this.poundRoomId = poundRoomId;
    }
    public Long getCameraId() {
        return cameraId;
    }

    public void setCameraId(Long cameraId) {
        this.cameraId = cameraId;
    }
    public Long getWeigherId() {
        return weigherId;
    }

    public void setWeigherId(Long weigherId) {
        this.weigherId = weigherId;
    }
    public Integer getWeighingMethod() {
        return weighingMethod;
    }

    public void setWeighingMethod(Integer weighingMethod) {
        this.weighingMethod = weighingMethod;
    }
    public Integer getPrint() {
        return print;
    }

    public void setPrint(Integer print) {
        this.print = print;
    }
    public Integer getSendOrReceive() {
        return sendOrReceive;
    }

    public void setSendOrReceive(Integer sendOrReceive) {
        this.sendOrReceive = sendOrReceive;
    }
    public Long getFirstTimeId() {
        return firstTimeId;
    }

    public void setFirstTimeId(Long firstTimeId) {
        this.firstTimeId = firstTimeId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}
